==> knative-model-4.12.0-sources.jar: annotations/io/fabric8/knative/messaging/v1/InMemoryChannelBuilder.java <==
package io.fabric8.knative.messaging.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class InMemoryChannelBuilder extends InMemoryChannelFluentImpl<InMemoryChannelBuilder> implements VisitableBuilder<InMemoryChannel,InMemoryChannelBuilder> {

    InMemoryChannelFluent<?> fluent;
    Boolean validationEnabled;

    public InMemoryChannelBuilder() { 
        this(true);
    }


    public InMemoryChannelBuilder(Boolean validationEnabled) { 
        this(new InMemoryChannel(), validationEnabled);
    }


    public InMemoryChannelBuilder(InMemoryChannelFluent<?> fluent) { 
        this(fluent, true);
    }


    public InMemoryChannelBuilder(InMemoryChannelFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new InMemoryChannel(), validationEnabled);
    }


    public InMemoryChannelBuilder(InMemoryChannelFluent<?> fluent,InMemoryChannel instance) { 
        this(fluent, instance, true);
    }


    public InMemoryChannelBuilder(InMemoryChannelFluent<?> fluent,InMemoryChannel instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        fluent.withSpec(instance.getSpec()); 
        fluent.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }


    public InMemoryChannelBuilder(InMemoryChannel instance) { 
        this(instance,true);
    }


    public InMemoryChannelBuilder(InMemoryChannel instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.withSpec(instance.getSpec()); 
        this.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }


    public InMemoryChannel build() {
        InMemoryChannel buildable = new InMemoryChannel(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        InMemoryChannelBuilder that = (InMemoryChannelBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> knative-model-5.0.2-sources.jar: annotations/io/fabric8/knative/messaging/v1/InMemoryChannelBuilder.java <==
package io.fabric8.knative.messaging.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class InMemoryChannelBuilder extends InMemoryChannelFluentImpl<InMemoryChannelBuilder> implements VisitableBuilder<InMemoryChannel,InMemoryChannelBuilder> {

    InMemoryChannelFluent<?> fluent;
    Boolean validationEnabled;

    public InMemoryChannelBuilder() {
        this(true);
    }

    public InMemoryChannelBuilder(Boolean validationEnabled) {
        this(new InMemoryChannel(), validationEnabled);
    }

    public InMemoryChannelBuilder(InMemoryChannelFluent<?> fluent) {
        this(fluent, true);
    }

    public InMemoryChannelBuilder(InMemoryChannelFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new InMemoryChannel(), validationEnabled);
    }

    public InMemoryChannelBuilder(InMemoryChannelFluent<?> fluent,InMemoryChannel instance) {
        this(fluent, instance, true);
    }

    public InMemoryChannelBuilder(InMemoryChannelFluent<?> fluent,InMemoryChannel instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        fluent.withSpec(instance.getSpec()); 
        fluent.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public InMemoryChannelBuilder(InMemoryChannel instance) {
        this(instance,true);
    }

    public InMemoryChannelBuilder(InMemoryChannel instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.withSpec(instance.getSpec()); 
        this.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.knative.messaging.v1.EditableInMemoryChannel build() {
        EditableInMemoryChannel buildable = new EditableInMemoryChannel(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        InMemoryChannelBuilder that = (InMemoryChannelBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
